@@ -33,7 +33,7 @@
 
 #include <libedataserver/e-sexp.h>
 #include <e-util/e-uid.h>
-#include <gal/util/e-util.h>
+#include <e-util/e-util.h>
 #include <libebook/e-address-western.h>
 #include <libebook/e-contact.h>
 #include <libedata-book/e-data-book.h>
@@ -47,15 +47,15 @@
 #include <camel/camel-multipart.h>
 #include <camel/camel-stream-mem.h>
 
-#include "e2k-context.h"
-#include "e2k-propnames.h"
-#include "e2k-restriction.h"
-#include "e2k-uri.h"
-#include "e2k-utils.h"
-#include "mapi.h"
-#include "exchange-account.h"
-#include "exchange-hierarchy.h"
-#include "e-folder-exchange.h"
+#include <e2k-context.h>
+#include <e2k-propnames.h>
+#include <e2k-restriction.h>
+#include <e2k-uri.h>
+#include <e2k-utils.h>
+#include <mapi.h>
+#include <exchange-account.h>
+#include <exchange-hierarchy.h>
+#include <e-folder-exchange.h>
 #include "e-book-backend-exchange.h"
 #include "exchange-component.h"
 
@@ -1119,7 +1119,7 @@ static GByteArray *
 build_message (const char *from_name, const char *from_email,
 	       const char *subject, const char *note, EContactPhoto *photo)
 {
-	CamelDataWrapper *wrapper;
+	CamelDataWrapper *wrapper = NULL;
 	CamelContentType *type;
 	CamelMimeMessage *msg;
 	CamelInternetAddress *from;
@@ -2239,9 +2239,15 @@ e_book_backend_exchange_load_source (EBookBackend *backend,
 static EBookBackendSyncStatus
 e_book_backend_exchange_remove (EBookBackendSync *backend, EDataBook *book, guint32 opid)
 {
-	d(printf("ebbe_remove(%p, %p)\n", backend, book));
-	return GNOME_Evolution_Addressbook_PermissionDenied;
+	EBookBackendExchange *be = E_BOOK_BACKEND_EXCHANGE (backend);
+	EBookBackendExchangePrivate *bepriv = be->priv;
+	ExchangeAccountFolderResult result;
+	const char *uri;
 
+	d(printf("ebbe_remove(%p, %p)\n", backend, book));
+	uri = e_folder_exchange_get_internal_uri (bepriv->folder);
+	result = exchange_account_remove_folder (bepriv->account, uri);
+	return GNOME_Evolution_Addressbook_Success;
 	/* FIXME: Folder deletion from contacts view */
 #if 0 
 	EBookBackendExchange *be = E_BOOK_BACKEND_EXCHANGE (backend);
